pub enum Error {
Io(Error),
UnknownModel,
InvalidChannel,
}Expand description
Errors that can occur when accessing the PWM peripheral.
Variants
Io(Error)
I/O error.
UnknownModel
Unknown model.
The Raspberry Pi model or SoC can’t be identified. Support for new models is usually added shortly after they are officially announced and available to the public. Make sure you’re using the latest release of RPPAL.
You may also encounter this error if your Linux distribution doesn’t provide any of the common user-accessible system files that are used to identify the model and SoC.
InvalidChannel
Invalid channel.
The selected PWM channel is not available on this device. You may
encounter this error if the Raspberry Pi model only has a limited
number of channels, the selected channel hasn’t been properly
configured in /boot/firmware/config.txt, or the channel isn’t
supported by RPPAL.